from ..fil_PH import Provider as FilPhProvider


class Provider(FilPhProvider):
    """Implement lorem provider for ``tl_PH`` locale.

    There is no difference from the |FilPhLoremProvider|.

    .. |FilPhLoremProvider| replace::
        :meth:`FilPhLoremProvider <faker.providers.lorem.fil_PH.Provider>`
    """

    pass
